pub struct MemoryPublisher { /* private fields */ }Expand description
A sink that sends messages to an in-memory channel.
Implementations
Sourceimpl MemoryPublisher
impl MemoryPublisher
pub fn new(config: &MemoryConfig) -> Result<Self>
pub async fn new_async(config: &MemoryConfig) -> Result<Self>
Sourcepub fn new_local(topic: &str, capacity: usize) -> Self
pub fn new_local(topic: &str, capacity: usize) -> Self
Creates a new local memory publisher.
This method creates a new in-memory publisher with the specified topic and capacity. The publisher will send messages to the in-memory channel for the specified topic.
Sourcepub fn channel(&self) -> MemoryChannel
pub fn channel(&self) -> MemoryChannel
Note: This helper is primarily for tests expecting a Queue.
If used on a broadcast publisher, it will create a separate Queue channel.