pub struct ResponsePublisher;Expand description
A publisher that simply returns the message it receives as a response. This is useful when used with a Handler to reflect the handler’s output back to the source (e.g., for HTTP request-response).