pub struct StreamBufferPublisher { /* private fields */ }Expand description
Publisher side of the stream_buffer endpoint.
send appends a message to the partition selected by
message.metadata["correlation_id"]. It does not accept messages without a
correlation id because otherwise consumers could not safely read one stream
without also consuming another stream’s responses.
Implementations
Sourceimpl StreamBufferPublisher
impl StreamBufferPublisher
pub fn new(config: &StreamBufferConfig) -> Result<Self>