Module event_handler

Module event_handler 

Structs

EventPublisher
A publisher middleware that intercepts messages and passes them to a Handler. This middleware is terminal; it consumes the message and does not pass it to an inner publisher.