FileConsumerMode

Enum FileConsumerMode 

pub enum FileConsumerMode {
    Consume {
        delete: bool,
    },
    Subscribe {
        delete: bool,
    },
    GroupSubscribe {
        group_id: String,
        read_from_tail: bool,
    },
}

Variants



Consume

Queue Mode: Standard point-to-point consumption. Reads from the start of the file. If delete is true, processed lines are physically removed from the file once they are successfully acknowledged.

Fields

delete: bool


Subscribe

Broadcast Mode: Pub-sub style consumption. Tails the file by starting at the current end. If delete is true, lines are removed only after all local application subscribers for this specific file have acknowledged them.

Fields

delete: bool


GroupSubscribe

Persistent Mode: Consumption with external offset tracking. Saves the last read byte position to a .offset file identified by the group_id. This allows the consumer to resume exactly where it left off after a restart without deleting data or requiring the bridge to stay running.

Fields

group_id: String

The consumer group ID that is used for offset tracking. Should be unique.

read_from_tail: bool

If true, starts reading from the end of the file if no offset is stored. If false, starts reading from the beginning.