pub enum FileFormat {
Normal,
Json,
Text,
Raw,
}Expand description
Format for messages written to or read from a file.
Variants
Normal
The full CanonicalMessage is serialized to JSON. Payload is a byte array.
Json
The full CanonicalMessage is serialized to JSON. Payload is rendered as a JSON value if possible.
Text
The full CanonicalMessage is serialized to JSON. Payload is rendered as a string if possible.
Raw
The raw payload of the message is written. For consumers, the line is read as raw bytes.