DeadLetterQueueMiddleware

Struct DeadLetterQueueMiddleware 

pub struct DeadLetterQueueMiddleware {
    pub endpoint: Endpoint,
}
Dead-Letter Queue (DLQ) middleware configuration.

Routes failed messages to a designated endpoint for later analysis and recovery. It is recommended to pair this with the Retry middleware to avoid message loss.

Failed messages are sent to the configured endpoint when they are exhausted after retry attempts.

Fields

endpoint: Endpoint

The endpoint to send failed messages to.