pub struct FileConfig {
pub path: String,
pub delimiter: Option<String>,
pub mode: Option<FileConsumerMode>,
pub format: FileFormat,
}Fields
path: StringPath to the file.
delimiter: Option<String>Optional delimiter for messages. Defaults to newline (“\n”). Can be a string or a hex sequence (e.g. “0x00”). Currently only single-byte delimiters are supported.
mode: Option<FileConsumerMode>The consumption mode. If not specified, defaults to consume.
For publishers, this setting is ignored.
format: FileFormatThe format for writing messages to the file (Publisher) or interpreting them (Consumer). Defaults to normal.
Implementations
Sourceimpl FileConfig
impl FileConfig
Sourcepub fn new(path: impl Into<String>) -> Self
pub fn new(path: impl Into<String>) -> Self
Creates a new File configuration with the specified path.
pub fn with_mode(self, mode: FileConsumerMode) -> Self
Sourcepub fn effective_mode(&self) -> FileConsumerMode
pub fn effective_mode(&self) -> FileConsumerMode
Returns the effective consumer mode, defaulting to Consume if not set.