pub enum Sent {
Ack,
Response(CanonicalMessage),
}Expand description
The outcome of a successful single message publishing operation.
Variants
Ack
Message was successfully sent, no response was generated.
Response(CanonicalMessage)
Message was successfully sent and a response was generated.