pub enum SentBatch {
Ack,
Partial {
responses: Option<Vec<CanonicalMessage>>,
failed: Vec<(CanonicalMessage, PublisherError)>,
},
}Expand description
The outcome of a successful batch message publishing operation.
Variants
Ack
All messages in the batch were sent successfully. No responses were generated.
Partial
The batch operation resulted in a mix of successes and/or failures.