into_commit_func

Function into_commit_func 

pub fn into_commit_func(batch_commit: BatchCommitFunc) -> CommitFunc
Converts a BatchCommitFunc into a CommitFunc by wrapping it. This allows a function that commits a batch of messages to be used where a function that commits a single message is expected.