Structs
- Event
Publisher - A publisher middleware that intercepts messages and passes them to a
Handler. This middleware is terminal; it consumes the message and does not pass it to an inner publisher.
Handler.
This middleware is terminal; it consumes the message and does not pass it to an inner publisher.